@@ -26,7 +26,8 @@ async def schedule_plan(plan: Plan) -> None:
 
                 deployment = await fetch_deployment(plan, settings)
                 gh_token = deployment["definition"]["token"]
-                if not gh_token:
+                if gh_token is None:
+                    logger.debug("Using the environment GITHUB_TOKEN")
                     gh_token = os.getenv("GITHUB_TOKEN")
 
                 if not gh_token:
@@ -55,6 +56,8 @@ async def schedule_plan(plan: Plan) -> None:
                     "GITHUB_REF_NAME", settings.plan.providers.github.ref
                 )
 
+                reliably_token = settings.agent.token.get_secret_value()
+
                 url = (
                     f"{gh_api_url}/repos/{gh_repo}/actions"
                     f"/workflows/{gh_workflow_id}/dispatches"
@@ -70,7 +73,11 @@ async def schedule_plan(plan: Plan) -> None:
                         },
                         json={
                             "ref": gh_ref,
-                            "inputs": {"experiment-url": experiment_url},
+                            "inputs": {
+                                "experiment-url": experiment_url,
+                                "reliably-agent-token": reliably_token,
+                                "environment-name": "myenv",
+                            },
                         },
                     )
                     logger.info(r.status_code)
